@@ -8,9 +8,7 @@ from collections import Counter
 import operator
 import re
 import math
-import pandas
 import itertools
-import datetime
 import json
 import codecs
 import difflib
@@ -259,9 +257,9 @@ class AutoTag:
             features['contains(%s)' % word] = (word in document_words)
         return features
     
-    def get_tags(self,data):
+    def get_tags(self,data,n=5):
         tag_count = self.count_data([tag for status,tags in data for tag in tags],'tag_count.txt')
-        tags = [tag for tag,count in tag_count if count > 5]
+        tags = [tag for tag,count in tag_count if count > n]
 #         tags = tags[:20]
         return tags
     
@@ -271,7 +269,7 @@ class AutoTag:
         classifier = {}
         for tag in tags:
             print(tag)
-            featuresets = [(self.document_features(d), tag in c) for (d,c) in data]
+            featuresets = [(self.document_features(doc), tag in tags) for (doc,tags) in data if len(tags) > 0]
             classifier[tag] = nltk.NaiveBayesClassifier.train(featuresets)
             classifier[tag].show_most_informative_features(5)
         with open('classifier','w') as classifier_file:
